@@ -29,7 +29,6 @@
 #include "nautilus-file-utilities.h"
 #include "nautilus-file.h"
 #include "nautilus-icon-factory.h"
-#include "nautilus-sidebar-functions.h"
 #include <eel/eel-enumeration.h>
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-gtk-extensions.h>
@@ -98,7 +97,7 @@ static PreferenceImportType OLD_PREFERENCES_TO_IMPORT[] = {
 /* Enumerations used to qualify some INTEGER preferences */
 static EelEnumerationEntry speed_tradeoff_enum_entries[] = {
 	{ "always",	    N_("_Always"),		NAUTILUS_SPEED_TRADEOFF_ALWAYS },
-	{ "local_only",	    N_("_Local Files Only"),	NAUTILUS_SPEED_TRADEOFF_LOCAL_ONLY },
+	{ "local_only",	    N_("_Local File Only"),	NAUTILUS_SPEED_TRADEOFF_LOCAL_ONLY },
 	{ "never",	    N_("_Never"),		NAUTILUS_SPEED_TRADEOFF_NEVER },
 	{ NULL }
 };
@@ -342,16 +341,6 @@ static const PreferenceDefault preference_defaults[] = {
 	  NULL, NULL,
 	  "click_policy"
 	},
-	{ NAUTILUS_PREFERENCES_XALF_ENABLED,
-	  PREFERENCE_BOOLEAN,
-	  GINT_TO_POINTER (TRUE),
-	  NULL, NULL, NULL
-	},
-	{ NAUTILUS_PREFERENCES_XALF_OPTIONS,
-	  PREFERENCE_STRING_LIST,
-	  "",
-	  NULL, NULL, NULL
-	},
 	{ NAUTILUS_PREFERENCES_EXECUTABLE_TEXT_ACTIVATION,
 	  PREFERENCE_STRING,
 	  "ask",
@@ -382,7 +371,7 @@ static const PreferenceDefault preference_defaults[] = {
 	},
 	{ NAUTILUS_PREFERENCES_SHOW_SPECIAL_FLAGS,
 	  PREFERENCE_BOOLEAN,
-	  GINT_TO_POINTER (FALSE)
+	  GINT_TO_POINTER (TRUE)
 	},
 	{ NAUTILUS_PREFERENCES_SORT_DIRECTORIES_FIRST,
 	  PREFERENCE_BOOLEAN,
@@ -439,7 +428,7 @@ static const PreferenceDefault preference_defaults[] = {
 	},
 	{ NAUTILUS_PREFERENCES_TREE_SHOW_ONLY_DIRECTORIES,
 	  PREFERENCE_BOOLEAN,
-	  GINT_TO_POINTER (FALSE)
+	  GINT_TO_POINTER (TRUE)
 	},
 
 	/* Home URI */
@@ -497,39 +486,11 @@ static const PreferenceDefault preference_defaults[] = {
 	},
 	{ NAUTILUS_PREFERENCES_LIST_VIEW_DEFAULT_ZOOM_LEVEL,
 	  PREFERENCE_STRING,
-	  "small",
+	  "smaller",
 	  NULL, NULL,
 	  "default_zoom_level"
 	},
 
-	/* Sidebar panel default */
-	{ nautilus_sidebar_news_enabled_preference_name,
-	  PREFERENCE_BOOLEAN,
-	  GINT_TO_POINTER (TRUE)
-	},
-	{ nautilus_sidebar_notes_enabled_preference_name,
-	  PREFERENCE_BOOLEAN,
-	  GINT_TO_POINTER (TRUE)
-	},
-	{ nautilus_sidebar_history_enabled_preference_name,
-	  PREFERENCE_BOOLEAN,
-	  GINT_TO_POINTER (TRUE)
-	},
-	{ nautilus_sidebar_tree_enabled_preference_name,
-	  PREFERENCE_BOOLEAN,
-	  GINT_TO_POINTER (FALSE)
-	},
-
-	/* news panel preferences */
-	{ NAUTILUS_PREFERENCES_NEWS_MAX_ITEMS,
-	  PREFERENCE_INTEGER,
-	  GINT_TO_POINTER (6)
-	},
-	{ NAUTILUS_PREFERENCES_NEWS_UPDATE_INTERVAL,
-	  PREFERENCE_INTEGER,
-	  GINT_TO_POINTER (5)
-	},
-
 	/* non-visible preferences */
 	{ NAUTILUS_PREFERENCES_ADD_TO_SESSION,
 	  PREFERENCE_BOOLEAN,
