@@ -24,7 +24,7 @@
 
 #include <config.h>
 #include "fm-list-model.h"
-#include <libnautilus-private/eggtreemultidnd.h>
+#include <libegg/eggtreemultidnd.h>
 
 #include <string.h>
 #include <eel/eel-gtk-macros.h>
@@ -191,9 +191,10 @@ fm_list_model_get_value (GtkTreeModel *tree_model, GtkTreeIter *iter, int column
 	FMListModel *model;
 	NautilusFile *file;
 	char *str;
-	GdkPixbuf *icon;
+	GdkPixbuf *icon, *tmp;
 	int icon_size;
 	NautilusZoomLevel zoom_level;
+	int width, height;
 
 	model = (FMListModel *)tree_model;
 
@@ -225,6 +226,15 @@ fm_list_model_get_value (GtkTreeModel *tree_model, GtkTreeIter *iter, int column
 		zoom_level = fm_list_model_get_zoom_level_from_column_id (column);
 		icon_size = nautilus_get_icon_size_for_zoom_level (zoom_level);
 		icon = nautilus_icon_factory_get_pixbuf_for_file (file, NULL, icon_size);
+
+		height = gdk_pixbuf_get_height (icon);
+		if (height > icon_size) {
+			width = gdk_pixbuf_get_width (icon) * icon_size / height;
+			height = icon_size;
+			tmp = gdk_pixbuf_scale_simple (icon, width, height, GDK_INTERP_BILINEAR);
+			g_object_unref (icon);
+			icon = tmp;
+		}
 		g_value_set_object (value, icon);
 		g_object_unref (icon);
 		break;
