@@ -976,6 +976,30 @@ empty_trash_callback (GtkWidget *button, gpointer data)
 	nautilus_file_operations_empty_trash (window);
 }
 
+
+static void
+burn_cd_callback (GtkWidget *button, gpointer data)
+{
+	GError *error;
+	char *argv[] = { "nautilus-cd-burner", NULL};
+	char *text;
+
+	error = NULL;
+	if (!g_spawn_async (NULL,
+			    argv, NULL,
+			    G_SPAWN_SEARCH_PATH,
+			    NULL, NULL,
+			    NULL,
+			    &error)) {
+		text = g_strdup_printf (_("Unable to launch the cd burner application:\n%s"), error->message);
+		eel_show_error_dialog (text,
+				       _("Can't launch cd burner"),
+				       GTK_WINDOW (gtk_widget_get_toplevel (button)));
+		g_free (text);
+		g_error_free (error);
+	}
+}
+
 static void
 nautilus_information_panel_trash_state_changed_callback (NautilusTrashMonitor *trash_monitor,
 						gboolean state, gpointer callback_data)
@@ -1029,6 +1053,18 @@ nautilus_information_panel_update_buttons (NautilusInformationPanel *information
 		g_signal_connect_object (nautilus_trash_monitor_get (), "trash_state_changed",
 					 G_CALLBACK (nautilus_information_panel_trash_state_changed_callback), temp_button, 0);
 	}
+	if (eel_istr_has_prefix (information_panel->details->uri, "burn:")) {
+		/* FIXME: We don't use spaces to pad labels! */
+		temp_button = gtk_button_new_with_mnemonic (_("_Write contents to CD"));
+
+		gtk_box_pack_start (GTK_BOX (information_panel->details->button_box), 
+					temp_button, FALSE, FALSE, 0);
+		gtk_widget_show (temp_button);
+		information_panel->details->has_buttons = TRUE;
+					
+		g_signal_connect (temp_button, "clicked",
+				  G_CALLBACK (burn_cd_callback), NULL);
+	}
 	
 	/* Make buttons for each item in short list + "Open with..." catchall,
 	 * unless there aren't any applications at all in complete list. 
@@ -1109,12 +1145,11 @@ nautilus_information_panel_update_appearance (NautilusInformationPanel *informat
 static void
 background_metadata_changed_callback (NautilusInformationPanel *information_panel)
 {
-	GList *attributes;
+	NautilusFileAttributes attributes;
 	gboolean ready;
 
 	attributes = nautilus_mime_actions_get_minimum_file_attributes ();
 	ready = nautilus_file_check_if_ready (information_panel->details->file, attributes);
-	g_list_free (attributes);
 
 	if (ready) {
 		nautilus_information_panel_update_appearance (information_panel);
@@ -1132,7 +1167,7 @@ nautilus_information_panel_set_uri (NautilusInformationPanel *information_panel,
 			  const char* initial_title)
 {       
 	NautilusFile *file;
-	GList *attributes;
+	NautilusFileAttributes attributes;
 
 	g_return_if_fail (NAUTILUS_IS_INFORMATION_PANEL (information_panel));
 	g_return_if_fail (new_uri != NULL);
@@ -1166,7 +1201,6 @@ nautilus_information_panel_set_uri (NautilusInformationPanel *information_panel,
 
 	attributes = nautilus_mime_actions_get_minimum_file_attributes ();
 	nautilus_file_monitor_add (information_panel->details->file, information_panel, attributes);
-	g_list_free (attributes);
 
 	background_metadata_changed_callback (information_panel);
 
