@@ -272,6 +272,8 @@ ui_remove_idle_handler (NautilusWindow *window)
 void
 nautilus_window_ui_freeze (NautilusWindow *window)
 {
+	g_object_ref (window);
+
 	if (window->details->ui_change_depth == 0) {
 		ui_remove_idle_handler (window);
 	}
@@ -300,6 +302,8 @@ nautilus_window_ui_thaw (NautilusWindow *window)
 		|| window->details->ui_pending_initialize_menus_part_2)) {
 		ui_install_idle_handler (window);
 	}
+
+	g_object_unref (window);
 }
 
 /* Unconditionally synchronize the BonoboUI of WINDOW. */
@@ -821,6 +825,8 @@ nautilus_window_constructed (NautilusWindow *window)
 	nautilus_window_allow_forward (window, FALSE);
 	nautilus_window_allow_stop (window, FALSE);
 
+	nautilus_window_allow_burn_cd (window, FALSE);
+	
 	/* Set up undo manager */
 	nautilus_undo_manager_attach (window->application->undo_manager, G_OBJECT (window));	
 
@@ -959,11 +965,13 @@ nautilus_window_finalize (GObject *object)
 	if (window->details->shell_ui != NULL) {
 		bonobo_ui_component_unset_container (window->details->shell_ui, NULL);
 		bonobo_object_unref (window->details->shell_ui);
+		window->details->shell_ui = NULL;
 	}
 
 	if (window->details->status_ui != NULL) {
 		bonobo_ui_component_unset_container (window->details->status_ui, NULL);
 		bonobo_object_unref (window->details->status_ui);
+		window->details->status_ui = NULL;
 	}
 
 	nautilus_file_unref (window->details->viewed_file);
@@ -1515,7 +1523,7 @@ cancel_view_as_callback (NautilusWindow *window)
 void
 nautilus_window_load_view_as_menus (NautilusWindow *window)
 {
-	GList *attributes;
+	NautilusFileAttributes attributes;
 
         g_return_if_fail (NAUTILUS_IS_WINDOW (window));
 
@@ -1526,8 +1534,6 @@ nautilus_window_load_view_as_menus (NautilusWindow *window)
 				       attributes, 
 				       load_view_as_menus_callback,
 				       window);
-
-	g_list_free (attributes);
 }
 
 void
@@ -1723,6 +1729,15 @@ nautilus_window_allow_reload (NautilusWindow *window, gboolean allow)
 	nautilus_window_ui_thaw (window);
 }
 
+void
+nautilus_window_allow_burn_cd (NautilusWindow *window, gboolean allow)
+{
+	nautilus_window_ui_freeze (window);
+	nautilus_bonobo_set_hidden (window->details->shell_ui,
+				    NAUTILUS_COMMAND_BURN_CD, !allow);
+	nautilus_window_ui_thaw (window);
+}
+
 void
 nautilus_send_history_list_changed (void)
 {
@@ -2200,7 +2215,7 @@ void
 nautilus_window_set_viewed_file (NautilusWindow *window,
 				 NautilusFile *file)
 {
-	GList *attributes;
+	NautilusFileAttributes attributes;
 
 	if (window->details->viewed_file == file) {
 		return;
@@ -2217,9 +2232,8 @@ nautilus_window_set_viewed_file (NautilusWindow *window,
 	}
 
 	if (file != NULL) {
-		attributes = g_list_prepend (NULL, NAUTILUS_FILE_ATTRIBUTE_DISPLAY_NAME);
+		attributes = NAUTILUS_FILE_ATTRIBUTE_DISPLAY_NAME;
 		nautilus_file_monitor_add (file, window, attributes);
-		g_list_free (attributes);
 	}
 
 	nautilus_file_unref (window->details->viewed_file);
